<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        v-show="showLevel > 0"
        v-if="renderComponent"
        :table="table"
        @currentChange="(val) => (currentRow = val)"
        :uploadInfo="uploadInfo"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="LabelPrintConfig"
        :bottomOffset="showLevel === 1 ? 350 : 110"
        :fixedHeight="showLevel === 1 ? 350 : null"
      >
        <template #toolbar></template>
      </ttable>
      <div class="detailWrap">
        <div class="icons">
          <i class="el-icon-top" @click="iconTop" />
          <i class="el-icon-bottom" @click="iconBottom" />
        </div>
        <el-tabs
          @tab-click="tabClick"
          v-show="showLevel < 2"
          type="border-card"
          ref="tabs"
        >
          <el-tab-pane label="配置明细" type="card">
            <DetailList ref="DetailList" :indexInfo="currentRow" />
          </el-tab-pane>
          <el-tab-pane label="附件" type="card">
            <Attachment :indexInfo="currentRow" />
          </el-tab-pane>
        </el-tabs>
      </div>
      <!-- 弹窗, 新增 / 修改 -->
      <IndexForm
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      />
    </basic-container>
  </div>
</template>

<script>
import { fetchList, delObj } from '@/api/print/config'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { remote } from '@/api/admin/dict'
import IndexForm from './IndexForm'
import DetailList from './DetailList'
import Attachment from './Attachment'

export default {
  data() {
    const tt = (prop, label, config) => {
      const w = (label.length - 1) * 20 + 15
      return Object.assign(
        {
          minWidth: w,
          // width: w < 140 ? 140 : w,
          prop,
          label,
          sort: true,
          isTrue: true,
          isSearch: true,
          searchInfoType: 'text'
        },
        config
      )
    }
    return {
      ajaxFun: fetchList,
      addOrUpdateVisible: false,
      currentRow: null,
      uploadInfo: {
        isShow: false
      },
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'xxxx1', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          tt('labelUniqueCode', '标签身份码', {
            render: { fun: this.addOrUpdateHandle }
          }),
          tt('labelTypeDesc', '标签类别描述', {
            searchInfoType: 'select',
            formatter: this.formatLabelType,
            optList: () => {
              return this.labelTypeOptions
            }
          }),
          tt('labelDesc', '标签描述'),
          tt('labelSize', '标签尺寸'),
          tt('createUser', '创建人'),
          tt('createTime', '创建时间'),
          tt('updateUser', '更新人'),
          tt('updateTime', '更新时间')
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      labelTypeOptions: [],
      showLevel: 1,
      renderComponent: true
    }
  },
  components: {
    IndexForm,
    DetailList,
    Attachment,
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  created() {
    remote('label_type').then((response) => {
      if (response.data.code === 0) {
        this.labelTypeOptions = response.data.data
      }
    })
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.LabelPrintConfig.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除标签身份码：' + row.labelUniqueCode, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    // 表格字段格式化
    formatLabelType(row, column, cellValue) {
      for (let i = 0, len = this.labelTypeOptions.length; i < len; i++) {
        if (cellValue == this.labelTypeOptions[i].value) {
          return this.labelTypeOptions[i].label
        }
      }
    },
    iconTop() {
      if (this.showLevel > 0) {
        this.showLevel--
        if (this.showLevel === 1) {
          this.forceRerender()
        }
      }
    },
    iconBottom() {
      if (this.showLevel < 2) {
        this.showLevel++
        if (this.showLevel === 2) {
          this.forceRerender()
        }
      }
    },
    forceRerender() {
      this.renderComponent = false
      this.$nextTick(() => {
        this.renderComponent = true
      })
    },
    tabClick() {
      this.$refs.DetailList.doLayout()
    }
  }
}
</script>
<style lang="scss" scoped>
.detailWrap {
  border-top: 10px solid #f0f2f5;
  position: relative;
  min-height: 39px;
  .icons {
    position: absolute;
    top: 10px;
    right: 15px;
    z-index: 10;
    .el-icon-top,
    .el-icon-bottom {
      cursor: pointer;
      &:hover {
        color: #006eff;
      }
    }
  }
}
</style>
